﻿using Telerik.Windows;
using System.IO;
using Telerik.Windows.Zip;

namespace _383164_UploadExample.Web
{
	/// <summary>
	/// Summary description for UserUploadHandler
	/// </summary>
	public class UserUploadHandler : RadUploadHandler
	{
		public override bool SaveChunkData(string filePath, long position, byte[] buffer, int contentLength, out int savedBytes)
		{
			bool result = base.SaveChunkData(filePath, position, buffer, contentLength, out savedBytes);

			// Checks if this is the last chunk of each file
			if (this.IsFinalFileRequest())
			{

				FileStream fileStream = new FileStream(filePath, FileMode.Open);
				string folderPath = this.GetTargetFolder();

				//extract all files from archieve
				using (ZipPackage package = ZipPackage.Open(fileStream, FileAccess.Read))
				{
					foreach (var entry in package.ZipPackageEntries)
					{
						if (entry.Attributes != FileAttributes.Directory)
						{
							SaveFile(entry, folderPath);
						}
					}
				}

				File.Delete(filePath);
			}

			return result;
		}

		//Save the unzipped files
		private static void SaveFile(ZipPackageEntry entry, string folderPath)
		{
			Stream reader = entry.OpenInputStream();
			var fileName = folderPath + "\\" + entry.FileNameInZip;

			var directoryName = Path.GetDirectoryName(fileName);

			if (directoryName != null)
			{
				if (!Directory.Exists(directoryName))
				{
					Directory.CreateDirectory(directoryName);
				}

				FileStream writer = File.Create(folderPath + "\\" + entry.FileNameInZip);

				int size = 2048;
				byte[] data = new byte[2048];
				while (true)
				{
					size = reader.Read(data, 0, data.Length);
					if (size > 0)
						writer.Write(data, 0, size);
					else
						break;
				}
				writer.Close();
			}

		}
	}
}